==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/NetworkingV1beta1HTTPIngressPathFluentImpl.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class NetworkingV1beta1HTTPIngressPathFluentImpl<A extends NetworkingV1beta1HTTPIngressPathFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements NetworkingV1beta1HTTPIngressPathFluent<A>{

    private NetworkingV1beta1IngressBackendBuilder backend;
    private String path;

    public NetworkingV1beta1HTTPIngressPathFluentImpl(){
    }
    public NetworkingV1beta1HTTPIngressPathFluentImpl(NetworkingV1beta1HTTPIngressPath instance){
            this.withBackend(instance.getBackend());

            this.withPath(instance.getPath());

    }

    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public NetworkingV1beta1IngressBackend getBackend(){
            return this.backend!=null?this.backend.build():null;
    }

    public NetworkingV1beta1IngressBackend buildBackend(){
            return this.backend!=null?this.backend.build():null;
    }

    public A withBackend(NetworkingV1beta1IngressBackend backend){
            _visitables.get("backend").remove(this.backend);
            if (backend!=null){ this.backend= new NetworkingV1beta1IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
    }

    public Boolean hasBackend(){
            return this.backend != null;
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackend(){
            return new BackendNestedImpl();
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(NetworkingV1beta1IngressBackend item){
            return new BackendNestedImpl(item);
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editBackend(){
            return withNewBackendLike(getBackend());
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackend(){
            return withNewBackendLike(getBackend() != null ? getBackend(): new NetworkingV1beta1IngressBackendBuilder().build());
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(NetworkingV1beta1IngressBackend item){
            return withNewBackendLike(getBackend() != null ? getBackend(): item);
    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public A withNewPath(String arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuilder arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1){
            return (A)withPath(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            NetworkingV1beta1HTTPIngressPathFluentImpl that = (NetworkingV1beta1HTTPIngressPathFluentImpl) o;
            if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            return true;
    }


    public class BackendNestedImpl<N> extends NetworkingV1beta1IngressBackendFluentImpl<NetworkingV1beta1HTTPIngressPathFluent.BackendNested<N>> implements NetworkingV1beta1HTTPIngressPathFluent.BackendNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final NetworkingV1beta1IngressBackendBuilder builder;
    
            BackendNestedImpl(NetworkingV1beta1IngressBackend item){
                    this.builder = new NetworkingV1beta1IngressBackendBuilder(this, item);
            }
            BackendNestedImpl(){
                    this.builder = new NetworkingV1beta1IngressBackendBuilder(this);
            }
    
    public N and(){
            return (N) NetworkingV1beta1HTTPIngressPathFluentImpl.this.withBackend(builder.build());
    }
    public N endBackend(){
            return and();
    }

}


}

==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/NetworkingV1beta1HTTPIngressPathFluentImpl.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class NetworkingV1beta1HTTPIngressPathFluentImpl<A extends NetworkingV1beta1HTTPIngressPathFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements NetworkingV1beta1HTTPIngressPathFluent<A>{

    private NetworkingV1beta1IngressBackendBuilder backend;
    private String path;
    private String pathType;

    public NetworkingV1beta1HTTPIngressPathFluentImpl(){
    }
    public NetworkingV1beta1HTTPIngressPathFluentImpl(NetworkingV1beta1HTTPIngressPath instance){
            this.withBackend(instance.getBackend());

            this.withPath(instance.getPath());

            this.withPathType(instance.getPathType());

    }

    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public NetworkingV1beta1IngressBackend getBackend(){
            return this.backend!=null?this.backend.build():null;
    }

    public NetworkingV1beta1IngressBackend buildBackend(){
            return this.backend!=null?this.backend.build():null;
    }

    public A withBackend(NetworkingV1beta1IngressBackend backend){
            _visitables.get("backend").remove(this.backend);
            if (backend!=null){ this.backend= new NetworkingV1beta1IngressBackendBuilder(backend); _visitables.get("backend").add(this.backend);} return (A) this;
    }

    public Boolean hasBackend(){
            return this.backend != null;
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackend(){
            return new BackendNestedImpl();
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> withNewBackendLike(NetworkingV1beta1IngressBackend item){
            return new BackendNestedImpl(item);
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editBackend(){
            return withNewBackendLike(getBackend());
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackend(){
            return withNewBackendLike(getBackend() != null ? getBackend(): new NetworkingV1beta1IngressBackendBuilder().build());
    }

    public NetworkingV1beta1HTTPIngressPathFluent.BackendNested<A> editOrNewBackendLike(NetworkingV1beta1IngressBackend item){
            return withNewBackendLike(getBackend() != null ? getBackend(): item);
    }

    public String getPath(){
            return this.path;
    }

    public A withPath(String path){
            this.path=path; return (A) this;
    }

    public Boolean hasPath(){
            return this.path != null;
    }

    public A withNewPath(String arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuilder arg1){
            return (A)withPath(new String(arg1));
    }

    public A withNewPath(StringBuffer arg1){
            return (A)withPath(new String(arg1));
    }

    public String getPathType(){
            return this.pathType;
    }

    public A withPathType(String pathType){
            this.pathType=pathType; return (A) this;
    }

    public Boolean hasPathType(){
            return this.pathType != null;
    }

    public A withNewPathType(String arg1){
            return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(StringBuilder arg1){
            return (A)withPathType(new String(arg1));
    }

    public A withNewPathType(StringBuffer arg1){
            return (A)withPathType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            NetworkingV1beta1HTTPIngressPathFluentImpl that = (NetworkingV1beta1HTTPIngressPathFluentImpl) o;
            if (backend != null ? !backend.equals(that.backend) :that.backend != null) return false;
            if (path != null ? !path.equals(that.path) :that.path != null) return false;
            if (pathType != null ? !pathType.equals(that.pathType) :that.pathType != null) return false;
            return true;
    }


    public class BackendNestedImpl<N> extends NetworkingV1beta1IngressBackendFluentImpl<NetworkingV1beta1HTTPIngressPathFluent.BackendNested<N>> implements NetworkingV1beta1HTTPIngressPathFluent.BackendNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final NetworkingV1beta1IngressBackendBuilder builder;
    
            BackendNestedImpl(NetworkingV1beta1IngressBackend item){
                    this.builder = new NetworkingV1beta1IngressBackendBuilder(this, item);
            }
            BackendNestedImpl(){
                    this.builder = new NetworkingV1beta1IngressBackendBuilder(this);
            }
    
    public N and(){
            return (N) NetworkingV1beta1HTTPIngressPathFluentImpl.this.withBackend(builder.build());
    }
    public N endBackend(){
            return and();
    }

}


}
